@@ -75,6 +75,20 @@ class AlertPreference(models.Model):
     def backend_obj(self):
         return ALERT_BACKENDS[self.backend]
     
+    
+    
+class AdminAlert(models.Model):
+    title = models.CharField(max_length=250)
+    body = models.TextField()
+    
+    recipients = models.ManyToManyField(User, help_text="who should receive this message?")
+    
+    send_at = models.DateTimeField(default=datetime.now, help_text="schedule the sending of this message in the future")
+    draft = models.BooleanField(default=False, verbose_name="Save as draft (don't send/queue now)")
+    sent = models.BooleanField(default=False)
+    
+    
    
 import alert.listeners #@UnusedImport
-import alert.backends #@UnusedImport
\ No newline at end of file
+import alert.backends #@UnusedImport
+import alert.alerts #@UnusedImport
\ No newline at end of file
